@@ -673,7 +673,7 @@ def read_eman1_helicon(path, min_distance=0):
         if not helix_line.startswith("#helix"):
             raise ValueError("Line does not start with '#helix'")
         import re
-        result = re.findall('\d+.\d*',helix_line)
+        result = re.findall('\d+\.?\d*',helix_line)
         allnumbers = [float(r) for r in result]
         return allnumbers[:4]
 
