@@ -28,7 +28,8 @@ import argparse
 import json
 import multiprocessing
 import os
-
+import re
+import sys
 
 import numpy as np
 
@@ -235,10 +236,6 @@ def get_model(
         backend_weights = config["model"]["backend_weights"]
     from cryolo.frontend import YOLO
 
-    # import tensorflow as tf
-    # graph = tf.Graph()
-    # with graph.as_default():
-
     if num_gpus > 1:
         import tensorflow as tf
 
@@ -320,6 +317,49 @@ def _main_():
         **kwargs
     )()
 
+def setup_gpu(gpu_argument, gpu_fraction, num_cpu) -> int:
+    if isinstance(gpu_argument, list):
+        gpu_argument = [re.sub("[^0-9]", "", num) for num in gpu_argument if re.sub("[^0-9]", "", num).isnumeric()]
+        if len(gpu_argument) == 1:
+            str_gpus = gpu_argument[0].strip().split(" ")
+        else:
+            str_gpus = [str(entry) for entry in gpu_argument]
+        num_gpus = len(str_gpus)
+        os.environ["CUDA_VISIBLE_DEVICES"] = ",".join(str_gpus)
+    else:
+        num_gpus = 1
+        if gpu_argument != -1 and len(gpu_argument) > 0:
+            str_gpus = str(gpu_argument)
+            os.environ["CUDA_VISIBLE_DEVICES"] = ",".join(str_gpus)
+
+    ###############################
+    #   Setup amount of GPU memory used
+    ###############################
+    config_proto_args = {}
+
+    if num_cpu != -1:
+        config_proto_args["intra_op_parallelism_threads"] = num_cpu
+        config_proto_args["inter_op_parallelism_threads"] = num_cpu
+    if gpu_fraction < 1.0 and gpu_fraction > 0.0:
+        import tensorflow as tf
+        from keras.backend.tensorflow_backend import set_session
+
+        config = tf.compat.v1.ConfigProto(**config_proto_args)
+
+        config.gpu_options.allow_growth = True
+        config.gpu_options.per_process_gpu_memory_fraction = gpu_fraction
+
+        set_session(tf.compat.v1.Session(config=config))
+    else:
+        import tensorflow as tf
+        from keras.backend.tensorflow_backend import set_session
+
+        config = tf.compat.v1.ConfigProto(**config_proto_args)
+        config.gpu_options.allow_growth = True
+
+        set_session(tf.compat.v1.Session(config=config))
+
+    return num_gpus
 
 
 
@@ -347,44 +387,7 @@ def main(args=None):
     ###############################
     #   Setup which GPU is used
     ###############################
-    if isinstance(args.gpu, list):
-        if len(args.gpu) == 1:
-            str_gpus = args.gpu[0].strip().split(" ")
-        else:
-            str_gpus = [str(entry) for entry in args.gpu]
-        num_gpus = len(str_gpus)
-        os.environ["CUDA_VISIBLE_DEVICES"] = ",".join(str_gpus)
-    else:
-        num_gpus = 1
-        if args.gpu != -1 and len(args.gpu) > 0:
-            str_gpus = str(args.gpu)
-            os.environ["CUDA_VISIBLE_DEVICES"] = ",".join(str_gpus)
-
-    ###############################
-    #   Setup amount of GPU memory used
-    ###############################
-    config_proto_args = {}
-    if args.num_cpu != -1:
-        config_proto_args["intra_op_parallelism_threads"] = args.num_cpu
-        config_proto_args["inter_op_parallelism_threads"] = args.num_cpu
-    if args.gpu_fraction < 1.0 and args.gpu_fraction > 0.0:
-        import tensorflow as tf
-        from keras.backend.tensorflow_backend import set_session
-
-        config = tf.compat.v1.ConfigProto(**config_proto_args)
-
-        config.gpu_options.allow_growth = True
-        config.gpu_options.per_process_gpu_memory_fraction = args.gpu_fraction
-
-        set_session(tf.compat.v1.Session(config=config))
-    else:
-        import tensorflow as tf
-        from keras.backend.tensorflow_backend import set_session
-
-        config = tf.compat.v1.ConfigProto(**config_proto_args)
-        config.gpu_options.allow_growth = True
-
-        set_session(tf.compat.v1.Session(config=config))
+    num_gpus = setup_gpu(args.gpu, args.gpu_fraction, args.num_cpu)
 
     early_stop = int(args.early)
     do_multiprocessing = False
@@ -591,7 +594,7 @@ def main(args=None):
     #####################################
 
     valid_imgs_paths = [item["filename"] for item in valid_imgs]
-    valid_annot_paths = [{"path":item["boxpath"]} if "z" not in item else {"path:":item["boxpath"], "slice":item["z"]} for item in valid_imgs]
+    valid_annot_paths = [{"path":item["boxpath"]} if "z" not in item else {"path":item["boxpath"], "slice":item["z"]} for item in valid_imgs]
     train_imgs_paths = [item["filename"] for item in train_imgs]
     train_annot_paths = [{"path":item["boxpath"]} if "z" not in item else {"path": item["boxpath"], "slice": item["z"]} for item in train_imgs]
 
@@ -812,6 +815,8 @@ def main(args=None):
 
 if __name__ == "__main__":
     start_method = "fork"
+    if sys.platform == "win32":
+        start_method = "spawn"
     try:
         os_start_method = os.environ["CRYOLO_MP_START"]
 
